@@ -46,7 +46,7 @@ import zlib
 from urllib import urlencode
 from wadllib.application import Application
 from lazr.uri import URI
-from errors import HTTPError
+from errors import error_for, HTTPError
 from _json import DatetimeJSONEncoder
 
 # A drop-in replacement for httplib2's safename.
@@ -256,6 +256,9 @@ class Browser:
                     # but the response code is 304 and there's no
                     # content. The only way to handle this is to raise
                     # an error.
+                    #
+                    # We don't use error_for() here because 304 is not
+                    # normally considered an error condition.
                     raise HTTPError(response, content)
             else:
                 # XXX leonardr 2010/04/12 bug=httplib2#97
@@ -272,9 +275,10 @@ class Browser:
                 # behavior in httplib2.
                 response.status = 200
             return response, content
-        # Turn non-2xx responses into exceptions.
-        if response.status // 100 != 2:
-            raise HTTPError(response, content)
+        # Turn non-2xx responses into appropriate HTTPError subclasses.
+        error = error_for(response, content)
+        if error is not None:
+            raise error
         return response, content
 
     def get(self, resource_or_uri, headers=None, return_response=False):
