@@ -330,8 +330,8 @@ class Resource(RestfulBase):
         try:
             return self.lp_get_parameter(attr)
         except KeyError:
-            raise AttributeError("'%s' object has no attribute '%s'"
-                                 % (self.__class__.__name__, attr))
+            raise AttributeError("%s object has no attribute '%s'"
+                % (self, attr))
 
     def lp_values_for(self, param_name):
         """Find the set of possible values for a parameter."""
